/**
/**
 * Fichier : PC-Epd_154b_low_memory.h
 * Auteur : Pascal Chour - www.pascalchour.fr
 * Date : 23 février 2018
 * (c) Pascal Chour 
 * Basé sur epd1in54b
 * Utilisable librement. Merci de préciser la source.
 *-------------------------------------------------------------------------- 
 * Cette bibliothèque permet de gérer un afficheur e-paper 1.54 pouce type B 
 * (pas de rafraichissement partiel) sur un microcontrôleur ne disposant que de
 * peu de RAM (typiquement, 2ko comme pour certains Arduino
 *
 * La bibliothèqe permet : 
 * - d'initialiser l'afficheur (cf. Waveshare)
 * - d'effacer l'écran
 * - de remplir l'écran
 * - d'afficher des lignes horizontale 
 * - d'afficher des textes
 * Le tout en utilisant très peu de RAM (moins de 300 octets de mémoire temporaire).
 *--------------------------------------------------------------------------
 * This library can managed a 1.54 inch e-paper display type B (no partial refresh) with
 * a low memory microcontroller (typically : some Arduino with 2kb RAM).
 * The functionalities of the library are :
 * - display management (init..., see Waveshare)
 * - clear the display
 * - fill the display
 * - draw horizontal line
 * - write text
 * The RAM used is lower than 300 bytes (temporary RAM).
 *--------------------------------------------------------------------------
 *  @filename   :   epd1in54b.h
 *  @brief      :   Header file for e-paper display library epd1in54b.cpp
 *  @author     :   Yehui from Waveshare
 *  
 *  Copyright (C) Waveshare     August 10 2017
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documnetation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to  whom the Software is
 * furished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS OR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#ifndef PC_EPD_154_LOW_MEMORY_H
#define PC_EPD_154_LOW_MEMORY_H

// Display resolution
#define EPD_WIDTH       200								// NB pixel en largeur
#define EPD_HEIGHT      200								// NB Pixel en hauteur
#define EPD_LINE_BYTE   (EPD_WIDTH / 8) 				// pour RED. Pour B&W, il faut multiplier par deux
#define EPD_MEM_BYTE	((EPD_WIDTH * EPD_HEIGHT) / 8)	// pour RED. Pour B&W, il faut multiplier par deux

#define  COLORED        true
#define  UNCOLORED      false
#define  RED			0x80 	// Choix couleur rouge (paramètre Color), choix du banc Rouge (paramètre Bank)
#define	 BLACK		    0x81 	// Choix couleur noire (ou rouge si banc Rouge), choix du banc Noir et Blanc (paramètre Bank)
#define	 INVERTED		COLORED // Inversion => Si banc Noir et Blanc, caractères Blanc et fond Noir. Si banc Rouge, caractères Blanc et fond Rouge
#define  NOTINVERTED	UNCOLORED


// EPD1IN54B commands
#define PANEL_SETTING                               0x00
#define POWER_SETTING                               0x01
#define POWER_OFF                                   0x02
#define POWER_OFF_SEQUENCE_SETTING                  0x03
#define POWER_ON                                    0x04
#define POWER_ON_MEASURE                            0x05
#define BOOSTER_SOFT_START                          0x06
#define DEEP_SLEEP                                  0x07
#define DATA_START_TRANSMISSION_1                   0x10
#define DATA_STOP                                   0x11
#define DISPLAY_REFRESH                             0x12
#define DATA_START_TRANSMISSION_2                   0x13
#define PLL_CONTROL                                 0x30
#define TEMPERATURE_SENSOR_COMMAND                  0x40
#define TEMPERATURE_SENSOR_CALIBRATION              0x41
#define TEMPERATURE_SENSOR_WRITE                    0x42
#define TEMPERATURE_SENSOR_READ                     0x43
#define VCOM_AND_DATA_INTERVAL_SETTING              0x50
#define LOW_POWER_DETECTION                         0x51
#define TCON_SETTING                                0x60
#define TCON_RESOLUTION                             0x61
#define SOURCE_AND_GATE_START_SETTING               0x62
#define GET_STATUS                                  0x71
#define AUTO_MEASURE_VCOM                           0x80
#define VCOM_VALUE                                  0x81
#define VCM_DC_SETTING_REGISTER                     0x82
#define PROGRAM_MODE                                0xA0
#define ACTIVE_PROGRAM                              0xA1
#define READ_OTP_DATA                               0xA2



typedef struct _tFont
{    
  const unsigned char *table;
  int Width;
  int Height;
  unsigned char Base;
  
} sFONT;


int  EpdInit(int cs, int dc, int rst, int busy);
void EpdSendCommand(unsigned char command);
void EpdSendData(unsigned char data);
void EpdWaitUntilIdle(void);
void EpdReset(void);
void EpdSetLutBw(void);
void EpdSetLutRed(void);
void EpdDisplayFrame(const unsigned char* frame_buffer_black, const unsigned char* frame_buffer_red);
void EpdSleep(void);
bool EpdSessionStart(int Bank);
void EpdSessionFill(bool Color);
void EpdSessionClose();
void EpdSessionClearDisplay();
void EpdSessionWriteString(unsigned int nrSpace, const char * text, int nrFont, bool InvertedChar, bool InvertedFill);
bool EpdSessionGoToLineAbs(unsigned int L, bool Color);
bool EpdSessionGoToLineRel(unsigned int L, bool Color);
int  EpdSessionGetFontWidth(int nrFont);
int  EpdSessionGetFontHeight(int nrFont);


#endif /* PC_EPD_154_LOW_MEMORY_H */

/* END OF FILE */
